# Flexible-Camera-Calibration
Flexible Camera Calibration

This project is a work in progress.

Demo's there show use of the different pats of this module:
- OldSchoolCC Chessboard: [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/SimonLBSoerensen/Flexible-Camera-Calibration/blob/master/Demos/OldSchoolCC.ipynb)

Python implementation of:
- Schöps, T., Larsson, V., Pollefeys, M., & Sattler, T. (2019). Why Having 10,000 Parameters in Your Camera Model is Better Than Twelve. http://arxiv.org/abs/1912.02908
- Ramalingam, S., & Sturm, P. (2017). A Unifying Model for Camera Calibration. IEEE Transactions on Pattern Analysis and Machine Intelligence, 39(7), 1309–1319. https://doi.org/10.1109/TPAMI.2016.2592904

# Installation
- Recommended: Install flexiblecc from PyPI: 
```sh
pip install flexiblecc
```
- Alternatively: install flexiblecc from the GitHub source:

First, clone flexiblecc using `git`:

```sh
git clone https://github.com/SimonLBSoerensen/Flexible-Camera-Calibration
```

Then, `cd` to the folder and run the install command:
```sh
cd Flexible-Camera-Calibration
python setup.py install
```